
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '33.2.0',
    'branch_nick': 'release-33',
    'revision_id': '18955be0a5c6d93525611b9bf62c4dc6ab659868',
    'revno': 12676
}
